==> DateTime-Locale-1.28.tar.gz: DateTime-Locale-1.28/share/ig.pl <==
{
  am_pm_abbreviated => [
    "A.M.",
    "P.M.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "MMM G y",
    GyMMMEd => "E, d MMM, G y",
    GyMMMd => "d MMM, G y",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-other" => "'Izu' W 'n'\N{U+2018}'ime' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'Izu' w 'n' 'ime' Y",
  },
  code => "ig",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} 'na' {0}",
  datetime_format_long => "{1} 'na' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "M\N{U+1ecd}n",
    "Tiu",
    "Wen",
    "T\N{U+1ecd}\N{U+1ecd}",
    "Fra\N{U+1ecb}",
    "Sat",
    "\N{U+1ee4}ka",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "M\N{U+1ecd}nde",
    "Tiuzdee",
    "Wenezdee",
    "T\N{U+1ecd}\N{U+1ecd}zdee",
    "Fra\N{U+1ecb}dee",
    "Sat\N{U+1ecd}dee",
    "S\N{U+1ecd}ndee",
  ],
  day_stand_alone_abbreviated => [
    "M\N{U+1ecd}n",
    "Tiu",
    "Wen",
    "T\N{U+1ecd}\N{U+1ecd}",
    "Fra\N{U+1ecb}",
    "Sat",
    "\N{U+1ee4}ka",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "M\N{U+1ecd}nde",
    "Tiuzdee",
    "Wenezdee",
    "T\N{U+1ecd}\N{U+1ecd}zdee",
    "Fra\N{U+1ecb}dee",
    "Sat\N{U+1ecd}dee",
    "S\N{U+1ecd}ndee",
  ],
  era_abbreviated => [
    "T.K.",
    "A.K.",
  ],
  era_narrow => [
    "T.K.",
    "A.K.",
  ],
  era_wide => [
    "Tupu Kraist",
    "Af\N{U+1ecd} Kra\N{U+1ecb}st",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Igbo",
  month_format_abbreviated => [
    "Jen",
    "Feb",
    "Maa",
    "Epr",
    "Mee",
    "Juu",
    "Jul",
    "\N{U+1ecc}g\N{U+1ecd}",
    "Sep",
    "\N{U+1ecc}kt",
    "Nov",
    "Dis",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "E",
    "M",
    "J",
    "J",
    "\N{U+1ecc}",
    "S",
    "\N{U+1ecc}",
    "N",
    "D",
  ],
  month_format_wide => [
    "Jen\N{U+1ee5}war\N{U+1ecb}",
    "Febr\N{U+1ee5}war\N{U+1ecb}",
    "Maach\N{U+1ecb}",
    "Epreel",
    "Mee",
    "Juun",
    "Jula\N{U+1ecb}",
    "\N{U+1ecc}g\N{U+1ecd}\N{U+1ecd}st",
    "Septemba",
    "\N{U+1ecc}ktoba",
    "Novemba",
    "Disemba",
  ],
  month_stand_alone_abbreviated => [
    "Jen",
    "Feb",
    "Maa",
    "Epr",
    "Mee",
    "Juu",
    "Jul",
    "\N{U+1ecc}g\N{U+1ecd}",
    "Sep",
    "\N{U+1ecc}kt",
    "Nov",
    "Dis",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "E",
    "M",
    "J",
    "J",
    "\N{U+1ecc}",
    "S",
    "\N{U+1ecc}",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Jen\N{U+1ee5}war\N{U+1ecb}",
    "Febr\N{U+1ee5}war\N{U+1ecb}",
    "Maach\N{U+1ecb}",
    "Epreel",
    "Mee",
    "Juun",
    "Jula\N{U+1ecb}",
    "\N{U+1ecc}g\N{U+1ecd}\N{U+1ecd}st",
    "Septemba",
    "\N{U+1ecc}ktoba",
    "Novemba",
    "Disemba",
  ],
  name => "Igbo",
  native_language => "As\N{U+1ee5}s\N{U+1ee5} Igbo",
  native_name => "As\N{U+1ee5}s\N{U+1ee5} Igbo",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+1ecc}1",
    "\N{U+1ecc}2",
    "\N{U+1ecc}3",
    "\N{U+1ecc}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+1ecc}kara 1",
    "\N{U+1ecc}kara 2",
    "\N{U+1ecc}kara 3",
    "\N{U+1ecc}kara 4",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+1ecc}1",
    "\N{U+1ecc}2",
    "\N{U+1ecc}3",
    "\N{U+1ecc}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+1ecc}kara 1",
    "\N{U+1ecc}kara 2",
    "\N{U+1ecc}kara 3",
    "\N{U+1ecc}kara 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 37,
}

==> DateTime-Locale-1.32.tar.gz: DateTime-Locale-1.32/share/ig.pl <==
{
  am_pm_abbreviated => [
    "A.M.",
    "P.M.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "MMM G y",
    GyMMMEd => "E, d MMM, G y",
    GyMMMd => "d MMM, G y",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-other" => "'Izu' W 'n'\N{U+2018}'ime' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'Izu' w 'n' 'ime' Y",
  },
  code => "ig",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} 'na' {0}",
  datetime_format_long => "{1} 'na' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "M\N{U+1ecd}n",
    "Tiu",
    "Wen",
    "T\N{U+1ecd}\N{U+1ecd}",
    "Fra\N{U+1ecb}",
    "Sat",
    "S\N{U+1ecd}n",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "M\N{U+1ecd}nde",
    "Tiuzdee",
    "Wenezdee",
    "T\N{U+1ecd}\N{U+1ecd}zdee",
    "Fra\N{U+1ecb}dee",
    "Sat\N{U+1ecd}dee",
    "S\N{U+1ecd}ndee",
  ],
  day_stand_alone_abbreviated => [
    "M\N{U+1ecd}n",
    "Tiu",
    "Wen",
    "T\N{U+1ecd}\N{U+1ecd}",
    "Fra\N{U+1ecb}",
    "Sat",
    "S\N{U+1ecd}n",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "M\N{U+1ecd}nde",
    "Tiuzdee",
    "Wenezdee",
    "T\N{U+1ecd}\N{U+1ecd}zdee",
    "Fra\N{U+1ecb}dee",
    "Sat\N{U+1ecd}dee",
    "S\N{U+1ecd}ndee",
  ],
  era_abbreviated => [
    "T.K.",
    "A.K.",
  ],
  era_narrow => [
    "T.K.",
    "A.K.",
  ],
  era_wide => [
    "Tupu Kraist",
    "Af\N{U+1ecd} Kra\N{U+1ecb}st",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Igbo",
  month_format_abbreviated => [
    "Jen",
    "Feb",
    "Maa",
    "Epr",
    "Mee",
    "Juu",
    "Jul",
    "\N{U+1ecc}g\N{U+1ecd}",
    "Sep",
    "\N{U+1ecc}kt",
    "Nov",
    "Dis",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "E",
    "M",
    "J",
    "J",
    "\N{U+1ecc}",
    "S",
    "\N{U+1ecc}",
    "N",
    "D",
  ],
  month_format_wide => [
    "Jen\N{U+1ee5}war\N{U+1ecb}",
    "Febr\N{U+1ee5}war\N{U+1ecb}",
    "Maach\N{U+1ecb}",
    "Epreel",
    "Mee",
    "Juun",
    "Jula\N{U+1ecb}",
    "\N{U+1ecc}g\N{U+1ecd}\N{U+1ecd}st",
    "Septemba",
    "\N{U+1ecc}ktoba",
    "Novemba",
    "Disemba",
  ],
  month_stand_alone_abbreviated => [
    "Jen",
    "Feb",
    "Maa",
    "Epr",
    "Mee",
    "Juu",
    "Jul",
    "\N{U+1ecc}g\N{U+1ecd}",
    "Sep",
    "\N{U+1ecc}kt",
    "Nov",
    "Dis",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "E",
    "M",
    "J",
    "J",
    "\N{U+1ecc}",
    "S",
    "\N{U+1ecc}",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Jen\N{U+1ee5}war\N{U+1ecb}",
    "Febr\N{U+1ee5}war\N{U+1ecb}",
    "Maach\N{U+1ecb}",
    "Epreel",
    "Mee",
    "Juun",
    "Jula\N{U+1ecb}",
    "\N{U+1ecc}g\N{U+1ecd}\N{U+1ecd}st",
    "Septemba",
    "\N{U+1ecc}ktoba",
    "Novemba",
    "Disemba",
  ],
  name => "Igbo",
  native_language => "Igbo",
  native_name => "Igbo",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+1ecc}1",
    "\N{U+1ecc}2",
    "\N{U+1ecc}3",
    "\N{U+1ecc}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+1ecc}kara 1",
    "\N{U+1ecc}kara 2",
    "\N{U+1ecc}kara 3",
    "\N{U+1ecc}kara 4",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+1ecc}1",
    "\N{U+1ecc}2",
    "\N{U+1ecc}3",
    "\N{U+1ecc}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+1ecc}kara 1",
    "\N{U+1ecc}kara 2",
    "\N{U+1ecc}kara 3",
    "\N{U+1ecc}kara 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 39,
}
